==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebCalendarDateEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarDateDescriptionMetadata } from "./CalendarDateDescriptionMetadata";
import { WebCalendarDateEventArgsDescription } from "./WebCalendarDateEventArgsDescription";
/**
 * @hidden
 */
var WebCalendarDateEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCalendarDateEventArgsDescriptionMetadata, _super);
    function WebCalendarDateEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCalendarDateEventArgsDescriptionMetadata.b = function (a) {
        if (WebCalendarDateEventArgsDescriptionMetadata.a == null) {
            WebCalendarDateEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCalendarDateEventArgsDescriptionMetadata.c(WebCalendarDateEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebCalendarDateEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebCalendarDateEventArgsDescriptionMetadata.a);
        CalendarDateDescriptionMetadata.d(a);
    };
    WebCalendarDateEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CalendarDateEventArgs");
        a.item("Detail", "ExportedType:CalendarDate");
    };
    WebCalendarDateEventArgsDescriptionMetadata.d = function (a) {
        WebCalendarDateEventArgsDescriptionMetadata.b(a);
        a.u("WebCalendarDateEventArgs", function () { return new WebCalendarDateEventArgsDescription(); });
        a.t("WebCalendarDateEventArgs", WebCalendarDateEventArgsDescriptionMetadata.a);
    };
    WebCalendarDateEventArgsDescriptionMetadata.$t = markType(WebCalendarDateEventArgsDescriptionMetadata, 'WebCalendarDateEventArgsDescriptionMetadata');
    WebCalendarDateEventArgsDescriptionMetadata.a = null;
    return WebCalendarDateEventArgsDescriptionMetadata;
}(Base));
export { WebCalendarDateEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebCalendarDateEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarDateDescriptionMetadata } from "./CalendarDateDescriptionMetadata";
import { WebCalendarDateEventArgsDescription } from "./WebCalendarDateEventArgsDescription";
/**
 * @hidden
 */
var WebCalendarDateEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCalendarDateEventArgsDescriptionMetadata, _super);
    function WebCalendarDateEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCalendarDateEventArgsDescriptionMetadata.b = function (a) {
        if (WebCalendarDateEventArgsDescriptionMetadata.a == null) {
            WebCalendarDateEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCalendarDateEventArgsDescriptionMetadata.c(WebCalendarDateEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebCalendarDateEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCalendarDateEventArgsDescriptionMetadata.a);
        CalendarDateDescriptionMetadata.d(a);
    };
    WebCalendarDateEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CalendarDateEventArgs");
        a.item("Detail", "ExportedType:CalendarDate");
    };
    WebCalendarDateEventArgsDescriptionMetadata.d = function (a) {
        WebCalendarDateEventArgsDescriptionMetadata.b(a);
        a.aa("WebCalendarDateEventArgs", function () { return new WebCalendarDateEventArgsDescription(); });
        a.z("WebCalendarDateEventArgs", WebCalendarDateEventArgsDescriptionMetadata.a);
    };
    WebCalendarDateEventArgsDescriptionMetadata.$t = markType(WebCalendarDateEventArgsDescriptionMetadata, 'WebCalendarDateEventArgsDescriptionMetadata');
    WebCalendarDateEventArgsDescriptionMetadata.a = null;
    return WebCalendarDateEventArgsDescriptionMetadata;
}(Base));
export { WebCalendarDateEventArgsDescriptionMetadata };
